==> haskell-cassava-megaparsec-2.0.4-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.0.4
visibility:           public
id:                   cassava-megaparsec-2.0.4-1hskSfc7JkKJbUpS7xeigD
key:                  cassava-megaparsec-2.0.4-1hskSfc7JkKJbUpS7xeigD
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  f72d7a13b9880f9816ba2d7fa2b831a7
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/cassava-megaparsec-2.0.4
hs-libraries:         HScassava-megaparsec-2.0.4-1hskSfc7JkKJbUpS7xeigD
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cassava-0.5.2.0-1OmefRYyWYo8ZRGDem2fkQ
    megaparsec-9.2.0-LBoFAUmElchJJ6l5qJIHyR
    unordered-containers-0.2.16.0-3GDkwMd2NkM63k39VNtCRt
    vector-0.12.3.1-3D3Ad9qttllIejNhiZMcEI

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.0.4-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cassava-megaparsec
version:              2.0.4
visibility:           public
id:                   cassava-megaparsec-2.0.4-4UP6rSRkwESKYEcKpG93au
key:                  cassava-megaparsec-2.0.4-4UP6rSRkwESKYEcKpG93au
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  9c56739faa67a185c8754e38b5d4339a
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cassava-megaparsec-2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/cassava-megaparsec-2.0.4
hs-libraries:         HScassava-megaparsec-2.0.4-4UP6rSRkwESKYEcKpG93au
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cassava-0.5.2.0-9F9t3VVhNlg2vADWdLkgw
    megaparsec-9.2.0-mq2j7EfyZ9JnOVbmrddm4
    unordered-containers-0.2.17.0-3BdVQ0XjWEwL87G4XZjXWP
    vector-0.12.3.1-5HK1DqtCbep8rMk53O5plV

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
